# Data sources
database(
    thermoLibraries = ['primaryThermoLibrary','KlippensteinH2O2', 'FFCM1(-)', 'aromatic_Burcat', 'phenol','DFT_QCI_thermo','C10H11', 'Fulvene_H', 'naphthalene_H'],
    reactionLibraries = [('Dooley/methylformate_all_N2bathgas', True), ('DBO', False),('C10H11',False), ('Fulvene_H',False), ('naphthalene_H',False), ('phenol_pyr', False)],
    seedMechanisms = ['FFCM1(-)', 'KlippensteinH2O2'],
    kineticsDepositories = ['training'], 
    kineticsFamilies = 'default',
    kineticsEstimator = 'rate rules',
)

# Constraints on generated species
generatedSpeciesConstraints(
    allowed=['input species','seed mechanisms','reaction libraries'],	
    maximumRadicalElectrons = 2,
    maximumOxygenAtoms = 4,
    maximumCarbonAtoms = 10,		
)

species(
    label='o-cresol',
    reactive=True,
    structure=SMILES("OC1C(C)=CC=CC=1"),
)

species(
    label='O2',
    reactive=True,
    structure=SMILES("[O][O]"),
)

species(
    label='N2',
    reactive=False,
    structure=InChI("InChI=1/N2/c1-2"),
)

species(
    label = 'butane',
    reactive = True,
    structure = SMILES("CCCC"),
)

species(
    label='butR1',
    reactive=True,
    structure=SMILES("CCC[CH2]"),
)

species(
    label='butR2',
    reactive=True,
    structure=SMILES("CC[CH]C"),
)

species(
    label='butROO1',
    reactive=True,
    structure=SMILES("CCCCO[O]"),
)

species(
    label='butROOH1',
    reactive=True,
    structure=SMILES("CCCCOO"),
)

species(
    label='butROO2',
    reactive=True,
    structure=SMILES("CC(O[O])CC"),
)

species(
    label='butROOH2',
    reactive=True,
    structure=SMILES("CC(OO)CC"),
)

species(
    label='butQOOH1',
    reactive=True,
    structure=SMILES("C[CH]CCOO"),
)

species(
    label='butQOOH2',
    reactive=True,
    structure=SMILES("[CH2]CC(OO)C"),
)

species(
    label='butOOQOOH1',
    reactive=True,
    structure=SMILES("CC(O[O])CCOO"),
)

species(
    label='butOOQOOH2',
    reactive=True,
    structure=SMILES("C(O[O])CC(OO)C"),
)

species(
    label='butKHP2',
    reactive=True,
    structure=SMILES("C(OO)CC(C)=O"),
)

species(
    label='butInt2',
    reactive=True,
    structure=SMILES("C(OO)C[C](C)OO"),
)

species(
    label='butInt1',
    reactive=True,
    structure=SMILES("[CH](OO)CC(C)OO"),
)

species(
    label='butKHP1',
    reactive=True,
    structure=SMILES("CC(OO)CC=O"),
)

species(
    label='butalkoxy1',
    reactive=True,
    structure=SMILES("CC([O])CC=O"),
)

species(
    label='butalkoxy2',
    reactive=True,
    structure=SMILES("[O]CCC(C)=O"),
)

species(
    label='propanone_rad',
    reactive=True,
    structure=SMILES("[CH2]C(C)=O"),
)

species(
    label='ethanone_rad',
    reactive=True,
    structure=SMILES("O=C[CH2]"),
)

species(
    label='dipropanone',
    reactive=True,
    structure=SMILES("O=CCC=O"),
)

simpleReactor(
    temperature=(650,'K'),
    pressure=(20,'bar'),
    initialMoleFractions={
    "butane": 3.11e-2,
    "O2": 2.03e-1,
    "N2": 0.762,
    "o-cresol": 3.46e-3,
    "butR1": 0,
    "butR2": 0,
    "butROO1": 0,
    "butROO2": 0,
    "butQOOH2": 0,
    "butROOH2": 0,
    "butROOH1": 0,
    "butOOQOOH1": 0,
    "butOOQOOH2": 0,
    "butInt1": 0,
    "butInt2": 0,
    "butKHP2": 0,
    "butKHP1": 0,
    "butalkoxy1": 0,
    "butalkoxy2": 0,
    "propanone_rad": 0,
    "ethanone_rad": 0,
    "dipropanone": 0,
    },
    terminationConversion={
        'butane': 0.99,
    },
)

simpleReactor(
    temperature=(800,'K'),
    pressure=(20,'bar'),
    initialMoleFractions={
    "butane": 3.11e-2,
    "O2": 2.03e-1,
    "N2": 0.762,
    "o-cresol": 3.46e-3,
    },
    terminationConversion={
        'butane': 0.99,
    },
)

simpleReactor(
    temperature=(1000,'K'),
    pressure=(20,'bar'),
    initialMoleFractions={
    "butane": 3.11e-2,
    "O2": 2.03e-1,
    "N2": 0.762,
    "o-cresol": 3.46e-3,
    },
    terminationConversion={
        'butane': 0.99,
    },
)

simpleReactor(
    temperature=(1250,'K'),
    pressure=(20,'bar'),
    initialMoleFractions={
    "butane": 3.11e-2,
    "O2": 2.03e-1,
    "N2": 0.762,
    "o-cresol": 3.46e-3,
    },
    terminationConversion={
        'butane': 0.99,
    },
)

simpleReactor(
    temperature=(2000,'K'),
    pressure=(20,'bar'),
    initialMoleFractions={
    "butane": 3.11e-2,
    "O2": 2.03e-1,
    "N2": 0.762,
    "o-cresol": 3.46e-3,
    },
    terminationConversion={
        'butane': 0.99,
    },
)

model(
    toleranceKeepInEdge=0.01,
    toleranceMoveToCore=0.1,
    toleranceInterruptSimulation=1e8,
    filterReactions=False,
    minCoreSizeForPrune=50,
    minSpeciesExistIterationsForPrune=2,
    maximumEdgeSpecies=100000,
)

simulator(
    atol=1e-16,
    rtol=1e-8,
)
#quantumMechanics(
#    software='mopac',
#    method='pm3',
    # fileStore='QMfiles', # relative to where you run it from. Defaults to inside the output folder if not defined.
#    scratchDirectory = None, # not currently used
#    onlyCyclics = True,
#    maxRadicalNumber = 0,
#    )

#pressureDependence(
#    method='modified strong collision',
#    maximumGrainSize=(0.5,'kcal/mol'),
#    minimumNumberOfGrains=250,
#    temperatures=(300,2000,'K',8),
#    pressures=(0.01,100,'bar',5),
#    interpolation=('Chebyshev', 6, 4),
#)

options(
    units='si',
#    drawMolecules=True,
    generatePlots=False,
)